mysql.result

Package mysql :: Module result |
[hide private]
[frames] | no frames]

# Module result

Result object for SQL queries.

The Result object is the result of the mysql.connection.Connection.execute method for SELECT-like queries.

There are also some objects (Row_Offset and Field) defined in this module that are returned by the Result object. These are described in more detail in the Result methods.

Classes | [hide private]
`` | Field The description of a column in a SELECT query.
`` | Result Query result object.
`` | Row_Offset Representation of a result offset.